@@ -73,7 +73,7 @@ find_predictors <- function(x, ...) {
 #' @export
 find_predictors.default <- function(x,
                                     effects = c("fixed", "random", "all"),
-                                    component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "instruments", "correlation", "smooth_terms"),
+                                    component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "instruments", "correlation", "smooth_terms"), # nolint
                                     flatten = FALSE,
                                     verbose = TRUE,
                                     ...) {
@@ -211,7 +211,7 @@ find_predictors.bfsl <- function(x, flatten = FALSE, verbose = TRUE, ...) {
 #' @export
 find_predictors.afex_aov <- function(x,
                                      effects = c("fixed", "random", "all"),
-                                     component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "instruments", "correlation", "smooth_terms"),
+                                     component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "instruments", "correlation", "smooth_terms"), # nolint
                                      flatten = FALSE,
                                      verbose = TRUE,
                                      ...) {
@@ -235,17 +235,27 @@ find_predictors.afex_aov <- function(x,
 .return_vars <- function(f, x) {
   l <- lapply(names(f), function(i) {
     if (i %in% c("random", "zero_inflated_random")) {
+      # random effects, just unlist
       unique(paste(unlist(f[[i]])))
     } else if (is.numeric(f[[i]])) {
       f[[i]]
+    } else if (is.list(f[[i]])) {
+      # this is for multivariate response models, where
+      # we have a list of formulas
+      lapply(f[[i]], function(j) unique(all.vars(j)))
     } else {
-      if (is.list(f[[i]])) {
-        # this is for multivariate response models, where
-        # we have a list of formulas
-        lapply(f[[i]], function(j) unique(all.vars(j)))
-      } else {
-        unique(all.vars(f[[i]]))
+      vars <- unique(all.vars(f[[i]]))
+      # when we have splines, the number of dimensions (argument "k") can be
+      # stored in a variable. This variable name is no predictor, so we remove it
+      # see #851
+      # check if we have splines in the formula
+      fs <- paste(as.character(f[[i]]), collapse = " ")
+      if (grepl(" s(", fs, fixed = TRUE) || grepl("+s(", fs, fixed = TRUE)) {
+        pattern <- "(.*)s\\((.*)k\\s?=(.*)\\)(.*)"
+        k_value <- trim_ws(gsub(pattern, "\\3", fs))
+        vars <- setdiff(vars, k_value)
       }
+      vars
     }
   })
 
@@ -296,12 +306,47 @@ find_predictors.afex_aov <- function(x,
     # for survival models, separate out strata element
     if (inherits(x, "coxph")) {
       f_cond <- safe_deparse(f[["conditional"]])
+      # remove namespace prefixes
+      f_cond <- .remove_namespace_from_string(f_cond)
 
       if (grepl("strata(", f_cond, fixed = TRUE)) {
+        # create regular expressions to find strata terms
         yes_strata <- ".*strata\\((.*)\\).*"
+        # This regular expression pattern in R matches any occurrence of the
+        # string "strata" followed by parentheses containing any characters (.*),
+        # optionally followed by any amount of whitespace (\\s*), and then followed
+        # by any number of +, |, or * characters ([\\+|\\*]*). It also matches
+        # any occurrence of +, |, or * characters followed by any amount of
+        # whitespace (\\s*), and then followed by the string "strata" followed
+        # by parentheses containing any characters (strata\\(.*\\)).
+        # Here's a breakdown of the regular expression:
+        # strata: Matches the string "strata".
+        # \\(: Matches an opening parenthesis.
+        # .*: Matches any character zero or more times.
+        # \\): Matches a closing parenthesis.
+        # \\s*: Matches any amount of whitespace zero or more times.
+        # [\\+|\\*]*: Matches any number of +, |, or * characters zero or more times.
+        # |: Alternation operator to match either the first or second pattern.
+        # [\\+|\\*]: Matches a +, |, or * character.
+        # \\s*: Matches any amount of whitespace zero or more times.
+        # strata: Matches the string "strata".
+        # \\(: Matches an opening parenthesis.
+        # .*: Matches any character zero or more times.
+        # \\): Matches a closing parenthesis.
         no_strata <- "strata\\(.*\\)\\s*[\\+|\\*]*|[\\+|\\*]\\s*strata\\(.*\\)"
-        strata <- gsub(yes_strata, "\\1", f_cond)
+
+        # find predictors used inside "strata()"
+        strata <- gsub(",", "+", gsub(yes_strata, "\\1", f_cond), fixed = TRUE)
+        # remove reserved terms from strata formula
+        pattern <- "\\b(na\\.group|shortlabel)\\b\\s*=\\s*[^\\(]*"
+        strata <- gsub(pattern, "", strata)
+        # remove trailing "+"
+        strata <- gsub("(.*)\\+$", "\\1", trim_ws(strata))
+
+        # find predictors used outside "strata()"
         non_strata <- trim_ws(gsub("~", "", gsub(no_strata, "\\1", f_cond), fixed = TRUE))
+
+        # create formula parts
         f$strata <- stats::reformulate(strata)
         f$conditional <- stats::reformulate(non_strata)
       }
