@@ -1128,6 +1128,26 @@ get_statistic.negbinirr <- get_statistic.logitor
 # Other models -------------------------------------------------------
 
 
+#' @export
+get_statistic.glmgee <- function(x, ...) {
+  junk <- utils::capture.output({
+    cs <- suppressWarnings(stats::coef(summary(x, corr = FALSE)))
+  })
+  stat <- stats::na.omit(cs[, "z-value"])
+
+  out <- data.frame(
+    Parameter = names(stat),
+    Statistic = as.vector(stat),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.nestedLogit <- function(x, component = "all", verbose = TRUE, ...) {
   cf <- as.data.frame(stats::coef(x))
@@ -1394,6 +1414,19 @@ get_statistic.ivprobit <- function(x, ...) {
 }
 
 
+#' @export
+get_statistic.svy2lme <- function(x, ...) {
+  out <- data.frame(
+    Parameter = rownames(x$beta),
+    Statistic = as.vector(x$beta / sqrt(diag(x$Vbeta))),
+    stringsAsFactors = FALSE
+  )
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.HLfit <- function(x, ...) {
   utils::capture.output(s <- summary(x)) # nolint
