@@ -106,6 +106,8 @@ n_parameters.sim.merMod <- n_parameters.merMod
 #' @export
 n_parameters.wbm <- n_parameters.merMod
 
+#' @export
+n_parameters.svy2lme <- n_parameters.merMod
 
 
 
@@ -246,8 +248,8 @@ n_parameters.gls <- function(x, ...) {
 n_parameters.logitr <- function(x, effects = c("all", "fixed", "random"), ...) {
   effects <- match.arg(effects)
   switch(effects,
-    "fixed" = x$n$parsFixed,
-    "random" = x$n$parsRandom,
+    fixed = x$n$parsFixed,
+    random = x$n$parsRandom,
     x$n$parsFixed + x$n$parsRandom
   )
 }
