@@ -267,7 +267,7 @@ test_that("get_predicted - glmer with matrix response", {
     cbind(incidence, size - incidence) ~ period + (1 | herd),
     data = cbpp, family = binomial
   )
-  grid <- get_datagrid(model, at = "period", range = "grid", preserve_range = FALSE)
+  grid <- get_datagrid(model, by = "period", range = "grid", preserve_range = FALSE)
   out <- as.data.frame(get_predicted(model, data = grid, ci = 0.95))
   expect_equal(out$Predicted, c(0.19808, 0.08392, 0.07402, 0.04843), tolerance = 1e-3)
   expect_equal(out$CI_low, c(0.1357, 0.04775, 0.0404, 0.02164), tolerance = 1e-3)
